Библиотека для форматирования чисел до 999 999 999 999 миллиардов в понятный вид с текстовым обозначением разрядов числа или без него.

Библиотека состоит из одной функции `nicer(num, description_number=False)`.
`num` – целое число.
`description_number` – логическое значение, по умолчанию False. Отвечает за вывод текстового описания разрядов числа.

Например:
```
print(nicer(125000))
>>> 125 000

print(nicer(125000, description_number=True))
>>> 125 тыс. 000
```
